==> DynamicJasper-5.1.0-sources.jar: ar/com/fdvs/dj/domain/DJValueFormatter.java <==
/*
 * DynamicJasper: A library for creating reports dynamically by specifying
 * columns, groups, styles, etc. at runtime. It also saves a lot of development
 * time in many cases! (http://sourceforge.net/projects/dynamicjasper)
 *
 * Copyright (C) 2008  FDV Solutions (http://www.fdvsolutions.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 *
 * License as published by the Free Software Foundation; either
 *
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 */

package ar.com.fdvs.dj.domain;

import ar.com.fdvs.dj.domain.entities.conditionalStyle.StatusLightCondition;

import java.util.Map;

/**
 * Powerful interface. The idea behind this is that anybody could implement </br>
 * this interface and redefine the evaluate method in order to show different results in a cell. </br>
 * Example: date formatting, money formatting, string trimming, etc. </br>
 * </br>
 * @see StatusLightCondition
 * </br>
 */
public interface DJValueFormatter {

	Object evaluate(Object value, Map fields, Map variables, Map parameters);
	String getClassName();

}

==> DynamicJasper-5.3.8-sources.jar: ar/com/fdvs/dj/domain/DJValueFormatter.java <==
/*
 * DynamicJasper: A library for creating reports dynamically by specifying
 * columns, groups, styles, etc. at runtime. It also saves a lot of development
 * time in many cases! (http://sourceforge.net/projects/dynamicjasper)
 *
 * Copyright (C) 2008  FDV Solutions (http://www.fdvsolutions.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 *
 * License as published by the Free Software Foundation; either
 *
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 */

package ar.com.fdvs.dj.domain;

import ar.com.fdvs.dj.domain.entities.conditionalStyle.StatusLightCondition;

import java.util.Map;

/**
 * Powerful interface. The idea behind this is that anybody could implement <br>
 * this interface and redefine the evaluate method in order to show different results in a cell. <br>
 * Example: date formatting, money formatting, string trimming, etc. <br>
 * <br>
 * @see StatusLightCondition
 * <br>
 */
public interface DJValueFormatter {

	Object evaluate(Object value, Map fields, Map variables, Map parameters);
	String getClassName();

}
